from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Devices.Bluetooth
import win32more.Windows.Devices.Bluetooth.Advertisement
import win32more.Windows.Devices.Bluetooth.Background
import win32more.Windows.Devices.Bluetooth.GenericAttributeProfile
import win32more.Windows.Devices.Bluetooth.Rfcomm
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Networking.Sockets
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.WinRT
class BluetoothEventTriggeringMode(Enum, Int32):
    Serial = 0
    Batch = 1
    KeepLatest = 2
class BluetoothLEAdvertisementPublisherTriggerDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Bluetooth.Background.IBluetoothLEAdvertisementPublisherTriggerDetails
    _classid_ = 'Windows.Devices.Bluetooth.Background.BluetoothLEAdvertisementPublisherTriggerDetails'
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.Devices.Bluetooth.Background.IBluetoothLEAdvertisementPublisherTriggerDetails) -> win32more.Windows.Devices.Bluetooth.Advertisement.BluetoothLEAdvertisementPublisherStatus: ...
    @winrt_mixinmethod
    def get_Error(self: win32more.Windows.Devices.Bluetooth.Background.IBluetoothLEAdvertisementPublisherTriggerDetails) -> win32more.Windows.Devices.Bluetooth.BluetoothError: ...
    @winrt_mixinmethod
    def get_SelectedTransmitPowerLevelInDBm(self: win32more.Windows.Devices.Bluetooth.Background.IBluetoothLEAdvertisementPublisherTriggerDetails2) -> win32more.Windows.Foundation.IReference[Int16]: ...
    Error = property(get_Error, None)
    SelectedTransmitPowerLevelInDBm = property(get_SelectedTransmitPowerLevelInDBm, None)
    Status = property(get_Status, None)
class BluetoothLEAdvertisementWatcherTriggerDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Bluetooth.Background.IBluetoothLEAdvertisementWatcherTriggerDetails
    _classid_ = 'Windows.Devices.Bluetooth.Background.BluetoothLEAdvertisementWatcherTriggerDetails'
    @winrt_mixinmethod
    def get_Error(self: win32more.Windows.Devices.Bluetooth.Background.IBluetoothLEAdvertisementWatcherTriggerDetails) -> win32more.Windows.Devices.Bluetooth.BluetoothError: ...
    @winrt_mixinmethod
    def get_Advertisements(self: win32more.Windows.Devices.Bluetooth.Background.IBluetoothLEAdvertisementWatcherTriggerDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.Bluetooth.Advertisement.BluetoothLEAdvertisementReceivedEventArgs]: ...
    @winrt_mixinmethod
    def get_SignalStrengthFilter(self: win32more.Windows.Devices.Bluetooth.Background.IBluetoothLEAdvertisementWatcherTriggerDetails) -> win32more.Windows.Devices.Bluetooth.BluetoothSignalStrengthFilter: ...
    Advertisements = property(get_Advertisements, None)
    Error = property(get_Error, None)
    SignalStrengthFilter = property(get_SignalStrengthFilter, None)
class GattCharacteristicNotificationTriggerDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Bluetooth.Background.IGattCharacteristicNotificationTriggerDetails
    _classid_ = 'Windows.Devices.Bluetooth.Background.GattCharacteristicNotificationTriggerDetails'
    @winrt_mixinmethod
    def get_Characteristic(self: win32more.Windows.Devices.Bluetooth.Background.IGattCharacteristicNotificationTriggerDetails) -> win32more.Windows.Devices.Bluetooth.GenericAttributeProfile.GattCharacteristic: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Devices.Bluetooth.Background.IGattCharacteristicNotificationTriggerDetails) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_mixinmethod
    def get_Error(self: win32more.Windows.Devices.Bluetooth.Background.IGattCharacteristicNotificationTriggerDetails2) -> win32more.Windows.Devices.Bluetooth.BluetoothError: ...
    @winrt_mixinmethod
    def get_EventTriggeringMode(self: win32more.Windows.Devices.Bluetooth.Background.IGattCharacteristicNotificationTriggerDetails2) -> win32more.Windows.Devices.Bluetooth.Background.BluetoothEventTriggeringMode: ...
    @winrt_mixinmethod
    def get_ValueChangedEvents(self: win32more.Windows.Devices.Bluetooth.Background.IGattCharacteristicNotificationTriggerDetails2) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.Bluetooth.GenericAttributeProfile.GattValueChangedEventArgs]: ...
    Characteristic = property(get_Characteristic, None)
    Error = property(get_Error, None)
    EventTriggeringMode = property(get_EventTriggeringMode, None)
    Value = property(get_Value, None)
    ValueChangedEvents = property(get_ValueChangedEvents, None)
class _GattServiceProviderConnection_Meta_(ComPtr.__class__):
    pass
class GattServiceProviderConnection(ComPtr, metaclass=_GattServiceProviderConnection_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Bluetooth.Background.IGattServiceProviderConnection
    _classid_ = 'Windows.Devices.Bluetooth.Background.GattServiceProviderConnection'
    @winrt_mixinmethod
    def get_TriggerId(self: win32more.Windows.Devices.Bluetooth.Background.IGattServiceProviderConnection) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Service(self: win32more.Windows.Devices.Bluetooth.Background.IGattServiceProviderConnection) -> win32more.Windows.Devices.Bluetooth.GenericAttributeProfile.GattLocalService: ...
    @winrt_mixinmethod
    def Start(self: win32more.Windows.Devices.Bluetooth.Background.IGattServiceProviderConnection) -> Void: ...
    @winrt_classmethod
    def get_AllServices(cls: win32more.Windows.Devices.Bluetooth.Background.IGattServiceProviderConnectionStatics) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Devices.Bluetooth.Background.GattServiceProviderConnection]: ...
    Service = property(get_Service, None)
    TriggerId = property(get_TriggerId, None)
    _GattServiceProviderConnection_Meta_.AllServices = property(get_AllServices, None)
class GattServiceProviderTriggerDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Bluetooth.Background.IGattServiceProviderTriggerDetails
    _classid_ = 'Windows.Devices.Bluetooth.Background.GattServiceProviderTriggerDetails'
    @winrt_mixinmethod
    def get_Connection(self: win32more.Windows.Devices.Bluetooth.Background.IGattServiceProviderTriggerDetails) -> win32more.Windows.Devices.Bluetooth.Background.GattServiceProviderConnection: ...
    Connection = property(get_Connection, None)
class IBluetoothLEAdvertisementPublisherTriggerDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Bluetooth.Background.IBluetoothLEAdvertisementPublisherTriggerDetails'
    _iid_ = Guid('{610eca86-3480-41c9-a918-7ddadf207e00}')
    @winrt_commethod(6)
    def get_Status(self) -> win32more.Windows.Devices.Bluetooth.Advertisement.BluetoothLEAdvertisementPublisherStatus: ...
    @winrt_commethod(7)
    def get_Error(self) -> win32more.Windows.Devices.Bluetooth.BluetoothError: ...
    Error = property(get_Error, None)
    Status = property(get_Status, None)
class IBluetoothLEAdvertisementPublisherTriggerDetails2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Bluetooth.Background.IBluetoothLEAdvertisementPublisherTriggerDetails2'
    _iid_ = Guid('{d4a3d025-c601-42d6-9829-4ccb3f5cd77f}')
    @winrt_commethod(6)
    def get_SelectedTransmitPowerLevelInDBm(self) -> win32more.Windows.Foundation.IReference[Int16]: ...
    SelectedTransmitPowerLevelInDBm = property(get_SelectedTransmitPowerLevelInDBm, None)
class IBluetoothLEAdvertisementWatcherTriggerDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Bluetooth.Background.IBluetoothLEAdvertisementWatcherTriggerDetails'
    _iid_ = Guid('{a7db5ad7-2257-4e69-9784-fee645c1dce0}')
    @winrt_commethod(6)
    def get_Error(self) -> win32more.Windows.Devices.Bluetooth.BluetoothError: ...
    @winrt_commethod(7)
    def get_Advertisements(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.Bluetooth.Advertisement.BluetoothLEAdvertisementReceivedEventArgs]: ...
    @winrt_commethod(8)
    def get_SignalStrengthFilter(self) -> win32more.Windows.Devices.Bluetooth.BluetoothSignalStrengthFilter: ...
    Advertisements = property(get_Advertisements, None)
    Error = property(get_Error, None)
    SignalStrengthFilter = property(get_SignalStrengthFilter, None)
class IGattCharacteristicNotificationTriggerDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Bluetooth.Background.IGattCharacteristicNotificationTriggerDetails'
    _iid_ = Guid('{9ba03b18-0fec-436a-93b1-f46c697532a2}')
    @winrt_commethod(6)
    def get_Characteristic(self) -> win32more.Windows.Devices.Bluetooth.GenericAttributeProfile.GattCharacteristic: ...
    @winrt_commethod(7)
    def get_Value(self) -> win32more.Windows.Storage.Streams.IBuffer: ...
    Characteristic = property(get_Characteristic, None)
    Value = property(get_Value, None)
class IGattCharacteristicNotificationTriggerDetails2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Bluetooth.Background.IGattCharacteristicNotificationTriggerDetails2'
    _iid_ = Guid('{727a50dc-949d-454a-b192-983467e3d50f}')
    @winrt_commethod(6)
    def get_Error(self) -> win32more.Windows.Devices.Bluetooth.BluetoothError: ...
    @winrt_commethod(7)
    def get_EventTriggeringMode(self) -> win32more.Windows.Devices.Bluetooth.Background.BluetoothEventTriggeringMode: ...
    @winrt_commethod(8)
    def get_ValueChangedEvents(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.Bluetooth.GenericAttributeProfile.GattValueChangedEventArgs]: ...
    Error = property(get_Error, None)
    EventTriggeringMode = property(get_EventTriggeringMode, None)
    ValueChangedEvents = property(get_ValueChangedEvents, None)
class IGattServiceProviderConnection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Bluetooth.Background.IGattServiceProviderConnection'
    _iid_ = Guid('{7fa1b9b9-2f13-40b5-9582-8eb78e98ef13}')
    @winrt_commethod(6)
    def get_TriggerId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Service(self) -> win32more.Windows.Devices.Bluetooth.GenericAttributeProfile.GattLocalService: ...
    @winrt_commethod(8)
    def Start(self) -> Void: ...
    Service = property(get_Service, None)
    TriggerId = property(get_TriggerId, None)
class IGattServiceProviderConnectionStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Bluetooth.Background.IGattServiceProviderConnectionStatics'
    _iid_ = Guid('{3d509f4b-0b0e-4466-b8cd-6ebdda1fa17d}')
    @winrt_commethod(6)
    def get_AllServices(self) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Devices.Bluetooth.Background.GattServiceProviderConnection]: ...
    AllServices = property(get_AllServices, None)
class IGattServiceProviderTriggerDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Bluetooth.Background.IGattServiceProviderTriggerDetails'
    _iid_ = Guid('{ae8c0625-05ff-4afb-b16a-de95f3cf0158}')
    @winrt_commethod(6)
    def get_Connection(self) -> win32more.Windows.Devices.Bluetooth.Background.GattServiceProviderConnection: ...
    Connection = property(get_Connection, None)
class IRfcommConnectionTriggerDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Bluetooth.Background.IRfcommConnectionTriggerDetails'
    _iid_ = Guid('{f922734d-2e3c-4efc-ab59-fc5cf96f97e3}')
    @winrt_commethod(6)
    def get_Socket(self) -> win32more.Windows.Networking.Sockets.StreamSocket: ...
    @winrt_commethod(7)
    def get_Incoming(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_RemoteDevice(self) -> win32more.Windows.Devices.Bluetooth.BluetoothDevice: ...
    Incoming = property(get_Incoming, None)
    RemoteDevice = property(get_RemoteDevice, None)
    Socket = property(get_Socket, None)
class IRfcommInboundConnectionInformation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Bluetooth.Background.IRfcommInboundConnectionInformation'
    _iid_ = Guid('{6d3e75a8-5429-4059-92e3-1e8b65528707}')
    @winrt_commethod(6)
    def get_SdpRecord(self) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_commethod(7)
    def put_SdpRecord(self, value: win32more.Windows.Storage.Streams.IBuffer) -> Void: ...
    @winrt_commethod(8)
    def get_LocalServiceId(self) -> win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId: ...
    @winrt_commethod(9)
    def put_LocalServiceId(self, value: win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId) -> Void: ...
    @winrt_commethod(10)
    def get_ServiceCapabilities(self) -> win32more.Windows.Devices.Bluetooth.BluetoothServiceCapabilities: ...
    @winrt_commethod(11)
    def put_ServiceCapabilities(self, value: win32more.Windows.Devices.Bluetooth.BluetoothServiceCapabilities) -> Void: ...
    LocalServiceId = property(get_LocalServiceId, put_LocalServiceId)
    SdpRecord = property(get_SdpRecord, put_SdpRecord)
    ServiceCapabilities = property(get_ServiceCapabilities, put_ServiceCapabilities)
class IRfcommOutboundConnectionInformation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Bluetooth.Background.IRfcommOutboundConnectionInformation'
    _iid_ = Guid('{b091227b-f434-4cb0-99b1-4ab8cedaedd7}')
    @winrt_commethod(6)
    def get_RemoteServiceId(self) -> win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId: ...
    @winrt_commethod(7)
    def put_RemoteServiceId(self, value: win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId) -> Void: ...
    RemoteServiceId = property(get_RemoteServiceId, put_RemoteServiceId)
class RfcommConnectionTriggerDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Bluetooth.Background.IRfcommConnectionTriggerDetails
    _classid_ = 'Windows.Devices.Bluetooth.Background.RfcommConnectionTriggerDetails'
    @winrt_mixinmethod
    def get_Socket(self: win32more.Windows.Devices.Bluetooth.Background.IRfcommConnectionTriggerDetails) -> win32more.Windows.Networking.Sockets.StreamSocket: ...
    @winrt_mixinmethod
    def get_Incoming(self: win32more.Windows.Devices.Bluetooth.Background.IRfcommConnectionTriggerDetails) -> Boolean: ...
    @winrt_mixinmethod
    def get_RemoteDevice(self: win32more.Windows.Devices.Bluetooth.Background.IRfcommConnectionTriggerDetails) -> win32more.Windows.Devices.Bluetooth.BluetoothDevice: ...
    Incoming = property(get_Incoming, None)
    RemoteDevice = property(get_RemoteDevice, None)
    Socket = property(get_Socket, None)
class RfcommInboundConnectionInformation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Bluetooth.Background.IRfcommInboundConnectionInformation
    _classid_ = 'Windows.Devices.Bluetooth.Background.RfcommInboundConnectionInformation'
    @winrt_mixinmethod
    def get_SdpRecord(self: win32more.Windows.Devices.Bluetooth.Background.IRfcommInboundConnectionInformation) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_mixinmethod
    def put_SdpRecord(self: win32more.Windows.Devices.Bluetooth.Background.IRfcommInboundConnectionInformation, value: win32more.Windows.Storage.Streams.IBuffer) -> Void: ...
    @winrt_mixinmethod
    def get_LocalServiceId(self: win32more.Windows.Devices.Bluetooth.Background.IRfcommInboundConnectionInformation) -> win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId: ...
    @winrt_mixinmethod
    def put_LocalServiceId(self: win32more.Windows.Devices.Bluetooth.Background.IRfcommInboundConnectionInformation, value: win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId) -> Void: ...
    @winrt_mixinmethod
    def get_ServiceCapabilities(self: win32more.Windows.Devices.Bluetooth.Background.IRfcommInboundConnectionInformation) -> win32more.Windows.Devices.Bluetooth.BluetoothServiceCapabilities: ...
    @winrt_mixinmethod
    def put_ServiceCapabilities(self: win32more.Windows.Devices.Bluetooth.Background.IRfcommInboundConnectionInformation, value: win32more.Windows.Devices.Bluetooth.BluetoothServiceCapabilities) -> Void: ...
    LocalServiceId = property(get_LocalServiceId, put_LocalServiceId)
    SdpRecord = property(get_SdpRecord, put_SdpRecord)
    ServiceCapabilities = property(get_ServiceCapabilities, put_ServiceCapabilities)
class RfcommOutboundConnectionInformation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Bluetooth.Background.IRfcommOutboundConnectionInformation
    _classid_ = 'Windows.Devices.Bluetooth.Background.RfcommOutboundConnectionInformation'
    @winrt_mixinmethod
    def get_RemoteServiceId(self: win32more.Windows.Devices.Bluetooth.Background.IRfcommOutboundConnectionInformation) -> win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId: ...
    @winrt_mixinmethod
    def put_RemoteServiceId(self: win32more.Windows.Devices.Bluetooth.Background.IRfcommOutboundConnectionInformation, value: win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId) -> Void: ...
    RemoteServiceId = property(get_RemoteServiceId, put_RemoteServiceId)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Security
import win32more.Windows.Win32.Security.Authorization.UI
import win32more.Windows.Win32.Security.DirectoryServices
import win32more.Windows.Win32.UI.Controls
DSSI_READ_ONLY: UInt32 = 1
DSSI_NO_ACCESS_CHECK: UInt32 = 2
DSSI_NO_EDIT_SACL: UInt32 = 4
DSSI_NO_EDIT_OWNER: UInt32 = 8
DSSI_IS_ROOT: UInt32 = 16
DSSI_NO_FILTER: UInt32 = 32
DSSI_NO_READONLY_MESSAGE: UInt32 = 64
@winfunctype('DSSEC.dll')
def DSCreateISecurityInfoObject(pwszObjectPath: win32more.Windows.Win32.Foundation.PWSTR, pwszObjectClass: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, ppSI: POINTER(win32more.Windows.Win32.Security.Authorization.UI.ISecurityInformation), pfnReadSD: win32more.Windows.Win32.Security.DirectoryServices.PFNREADOBJECTSECURITY, pfnWriteSD: win32more.Windows.Win32.Security.DirectoryServices.PFNWRITEOBJECTSECURITY, lpContext: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('DSSEC.dll')
def DSCreateISecurityInfoObjectEx(pwszObjectPath: win32more.Windows.Win32.Foundation.PWSTR, pwszObjectClass: win32more.Windows.Win32.Foundation.PWSTR, pwszServer: win32more.Windows.Win32.Foundation.PWSTR, pwszUserName: win32more.Windows.Win32.Foundation.PWSTR, pwszPassword: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, ppSI: POINTER(win32more.Windows.Win32.Security.Authorization.UI.ISecurityInformation), pfnReadSD: win32more.Windows.Win32.Security.DirectoryServices.PFNREADOBJECTSECURITY, pfnWriteSD: win32more.Windows.Win32.Security.DirectoryServices.PFNWRITEOBJECTSECURITY, lpContext: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('DSSEC.dll')
def DSCreateSecurityPage(pwszObjectPath: win32more.Windows.Win32.Foundation.PWSTR, pwszObjectClass: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, phPage: POINTER(win32more.Windows.Win32.UI.Controls.HPROPSHEETPAGE), pfnReadSD: win32more.Windows.Win32.Security.DirectoryServices.PFNREADOBJECTSECURITY, pfnWriteSD: win32more.Windows.Win32.Security.DirectoryServices.PFNWRITEOBJECTSECURITY, lpContext: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('DSSEC.dll')
def DSEditSecurity(hwndOwner: win32more.Windows.Win32.Foundation.HWND, pwszObjectPath: win32more.Windows.Win32.Foundation.PWSTR, pwszObjectClass: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, pwszCaption: win32more.Windows.Win32.Foundation.PWSTR, pfnReadSD: win32more.Windows.Win32.Security.DirectoryServices.PFNREADOBJECTSECURITY, pfnWriteSD: win32more.Windows.Win32.Security.DirectoryServices.PFNWRITEOBJECTSECURITY, lpContext: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFNDSCREATEISECINFO(param0: win32more.Windows.Win32.Foundation.PWSTR, param1: win32more.Windows.Win32.Foundation.PWSTR, param2: UInt32, param3: POINTER(win32more.Windows.Win32.Security.Authorization.UI.ISecurityInformation), param4: win32more.Windows.Win32.Security.DirectoryServices.PFNREADOBJECTSECURITY, param5: win32more.Windows.Win32.Security.DirectoryServices.PFNWRITEOBJECTSECURITY, param6: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFNDSCREATEISECINFOEX(param0: win32more.Windows.Win32.Foundation.PWSTR, param1: win32more.Windows.Win32.Foundation.PWSTR, param2: win32more.Windows.Win32.Foundation.PWSTR, param3: win32more.Windows.Win32.Foundation.PWSTR, param4: win32more.Windows.Win32.Foundation.PWSTR, param5: UInt32, param6: POINTER(win32more.Windows.Win32.Security.Authorization.UI.ISecurityInformation), param7: win32more.Windows.Win32.Security.DirectoryServices.PFNREADOBJECTSECURITY, param8: win32more.Windows.Win32.Security.DirectoryServices.PFNWRITEOBJECTSECURITY, param9: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFNDSCREATESECPAGE(param0: win32more.Windows.Win32.Foundation.PWSTR, param1: win32more.Windows.Win32.Foundation.PWSTR, param2: UInt32, param3: POINTER(win32more.Windows.Win32.UI.Controls.HPROPSHEETPAGE), param4: win32more.Windows.Win32.Security.DirectoryServices.PFNREADOBJECTSECURITY, param5: win32more.Windows.Win32.Security.DirectoryServices.PFNWRITEOBJECTSECURITY, param6: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFNDSEDITSECURITY(param0: win32more.Windows.Win32.Foundation.HWND, param1: win32more.Windows.Win32.Foundation.PWSTR, param2: win32more.Windows.Win32.Foundation.PWSTR, param3: UInt32, param4: win32more.Windows.Win32.Foundation.PWSTR, param5: win32more.Windows.Win32.Security.DirectoryServices.PFNREADOBJECTSECURITY, param6: win32more.Windows.Win32.Security.DirectoryServices.PFNWRITEOBJECTSECURITY, param7: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFNREADOBJECTSECURITY(param0: win32more.Windows.Win32.Foundation.PWSTR, param1: UInt32, param2: POINTER(win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR), param3: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFNWRITEOBJECTSECURITY(param0: win32more.Windows.Win32.Foundation.PWSTR, param1: UInt32, param2: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR, param3: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.HRESULT: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Microsoft.Windows.PushNotifications
import win32more.Windows.ApplicationModel.Background
import win32more.Windows.Foundation
import win32more.Windows.Win32.System.WinRT
class IPushNotificationChannel(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.PushNotifications.IPushNotificationChannel'
    _iid_ = Guid('{da28bbcb-7695-5d38-af82-f30b72fef1f6}')
    @winrt_commethod(6)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def get_ExpirationTime(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(8)
    def Close(self) -> Void: ...
    ExpirationTime = property(get_ExpirationTime, None)
    Uri = property(get_Uri, None)
class IPushNotificationCreateChannelResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.PushNotifications.IPushNotificationCreateChannelResult'
    _iid_ = Guid('{4df3717f-5d33-56e9-b381-1b350c95722e}')
    @winrt_commethod(6)
    def get_Channel(self) -> win32more.Microsoft.Windows.PushNotifications.PushNotificationChannel: ...
    @winrt_commethod(7)
    def get_ExtendedError(self) -> win32more.Windows.Foundation.HResult: ...
    @winrt_commethod(8)
    def get_Status(self) -> win32more.Microsoft.Windows.PushNotifications.PushNotificationChannelStatus: ...
    Channel = property(get_Channel, None)
    ExtendedError = property(get_ExtendedError, None)
    Status = property(get_Status, None)
class IPushNotificationManager(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.PushNotifications.IPushNotificationManager'
    _iid_ = Guid('{902f4aba-ff63-5dfe-a88f-15cc6bed55ff}')
    @winrt_commethod(6)
    def Register(self) -> Void: ...
    @winrt_commethod(7)
    def Unregister(self) -> Void: ...
    @winrt_commethod(8)
    def UnregisterAll(self) -> Void: ...
    @winrt_commethod(9)
    def CreateChannelAsync(self, remoteId: Guid) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.PushNotifications.PushNotificationCreateChannelResult, win32more.Microsoft.Windows.PushNotifications.PushNotificationCreateChannelStatus]: ...
    @winrt_commethod(10)
    def add_PushReceived(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.Windows.PushNotifications.PushNotificationManager, win32more.Microsoft.Windows.PushNotifications.PushNotificationReceivedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_PushReceived(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    PushReceived = event()
class IPushNotificationManagerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.PushNotifications.IPushNotificationManagerStatics'
    _iid_ = Guid('{71329470-1b55-58dc-a00c-68c26f2d8bd9}')
    @winrt_commethod(6)
    def IsSupported(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_Default(self) -> win32more.Microsoft.Windows.PushNotifications.PushNotificationManager: ...
    Default = property(get_Default, None)
class IPushNotificationReceivedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.PushNotifications.IPushNotificationReceivedEventArgs'
    _iid_ = Guid('{fbd4ec53-bb83-5495-8777-d3cf13e4299c}')
    @winrt_commethod(6)
    def get_Payload(self) -> ReceiveArray[Byte]: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.ApplicationModel.Background.BackgroundTaskDeferral: ...
    @winrt_commethod(8)
    def add_Canceled(self, handler: win32more.Windows.ApplicationModel.Background.BackgroundTaskCanceledEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_Canceled(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Payload = property(get_Payload, None)
    Canceled = event()
class PushNotificationChannel(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.PushNotifications.IPushNotificationChannel
    _classid_ = 'Microsoft.Windows.PushNotifications.PushNotificationChannel'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationChannel) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_ExpirationTime(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationChannel) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def Close(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationChannel) -> Void: ...
    ExpirationTime = property(get_ExpirationTime, None)
    Uri = property(get_Uri, None)
class PushNotificationChannelStatus(Enum, Int32):
    InProgress = 0
    InProgressRetry = 1
    CompletedSuccess = 2
    CompletedFailure = 3
class PushNotificationCreateChannelResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.PushNotifications.IPushNotificationCreateChannelResult
    _classid_ = 'Microsoft.Windows.PushNotifications.PushNotificationCreateChannelResult'
    @winrt_mixinmethod
    def get_Channel(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationCreateChannelResult) -> win32more.Microsoft.Windows.PushNotifications.PushNotificationChannel: ...
    @winrt_mixinmethod
    def get_ExtendedError(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationCreateChannelResult) -> win32more.Windows.Foundation.HResult: ...
    @winrt_mixinmethod
    def get_Status(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationCreateChannelResult) -> win32more.Microsoft.Windows.PushNotifications.PushNotificationChannelStatus: ...
    Channel = property(get_Channel, None)
    ExtendedError = property(get_ExtendedError, None)
    Status = property(get_Status, None)
class PushNotificationCreateChannelStatus(Structure):
    status: win32more.Microsoft.Windows.PushNotifications.PushNotificationChannelStatus
    extendedError: win32more.Windows.Foundation.HResult
    retryCount: UInt32
class _PushNotificationManager_Meta_(ComPtr.__class__):
    pass
class PushNotificationManager(ComPtr, metaclass=_PushNotificationManager_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.PushNotifications.IPushNotificationManager
    _classid_ = 'Microsoft.Windows.PushNotifications.PushNotificationManager'
    @winrt_mixinmethod
    def Register(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationManager) -> Void: ...
    @winrt_mixinmethod
    def Unregister(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationManager) -> Void: ...
    @winrt_mixinmethod
    def UnregisterAll(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationManager) -> Void: ...
    @winrt_mixinmethod
    def CreateChannelAsync(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationManager, remoteId: Guid) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.PushNotifications.PushNotificationCreateChannelResult, win32more.Microsoft.Windows.PushNotifications.PushNotificationCreateChannelStatus]: ...
    @winrt_mixinmethod
    def add_PushReceived(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationManager, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.Windows.PushNotifications.PushNotificationManager, win32more.Microsoft.Windows.PushNotifications.PushNotificationReceivedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PushReceived(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationManager, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def IsSupported(cls: win32more.Microsoft.Windows.PushNotifications.IPushNotificationManagerStatics) -> Boolean: ...
    @winrt_classmethod
    def get_Default(cls: win32more.Microsoft.Windows.PushNotifications.IPushNotificationManagerStatics) -> win32more.Microsoft.Windows.PushNotifications.PushNotificationManager: ...
    _PushNotificationManager_Meta_.Default = property(get_Default, None)
    PushReceived = event()
class PushNotificationReceivedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.PushNotifications.IPushNotificationReceivedEventArgs
    _classid_ = 'Microsoft.Windows.PushNotifications.PushNotificationReceivedEventArgs'
    @winrt_mixinmethod
    def get_Payload(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationReceivedEventArgs) -> ReceiveArray[Byte]: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationReceivedEventArgs) -> win32more.Windows.ApplicationModel.Background.BackgroundTaskDeferral: ...
    @winrt_mixinmethod
    def add_Canceled(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationReceivedEventArgs, handler: win32more.Windows.ApplicationModel.Background.BackgroundTaskCanceledEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Canceled(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationReceivedEventArgs, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Payload = property(get_Payload, None)
    Canceled = event()
PushNotificationsContract: UInt32 = 65536


make_ready(__name__)
